==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/zh_TW.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "通訊錄",
"Save" => "儲存",
"Uploading..." => "上傳中…",
"Importing..." => "匯入中…",
"Preparing..." => "準備中...",
"Imported {count} of {total} contacts" => "已匯入 {count}筆/共{total} 筆聯絡人資料",
"Imported {imported} contacts. {failed} failed." => "成功匯入{imported}筆聯絡人資料，有{failed}筆匯入失敗。",
"An address book called {name} already exists" => "通訊錄 {name} 已存在",
"Failed adding address book: {error}" => "通訊錄匯入失敗：{error}",
"Failed loading address books: {error}" => "通訊錄載入失敗：{error}",
"Indexing contacts" => "正在建立聯絡人索引...",
"Unrecoverable error loading address books: {msg}" => "載入通訊錄時發生無法修正的錯誤：{msg}",
"Error." => "錯誤。",
"Add to..." => "加入至…",
"Remove from..." => "從…移除",
"Add group..." => "新增群組",
"Invalid URL: \"{url}\"" => "無效的 URL ：\"{url}\"",
"There was an error opening a mail composer." => "開啟郵件編輯器發生錯誤。",
"Invalid email: \"{url}\"" => "無效的電子郵件：\"{url}\"",
"Merge failed. Cannot find contact: {id}" => "合併失敗，沒有找到聯絡人：{id}",
"Merge failed." => "合併失敗。",
"Merge failed. Error saving contact." => "合併失敗，儲存聯絡人時發生錯誤。",
"Select photo" => "選擇相片",
"Network or server error. Please inform administrator." => "網路或伺服器錯誤，請通知系統管理員。",
"Error adding to group." => "新增到群組時出錯。",
"Error removing from group." => "從群組中移除出錯。",
"Error setting {name} as favorite." => "設定 {name} 為最愛時發生錯誤。",
"Merge contacts" => "合併聯絡人",
"Cancel" => "取消",
"Add group" => "新增群組",
"OK" => "好",
"Could not find contact: {id}" => "找不到聯絡人：{id}",
"No files selected for upload." => "沒有選定上傳的檔案。",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "您想要上傳的檔案大小超過伺服器限制。",
"Edit profile picture" => "編輯大頭貼照",
"Crop photo" => "裁切相片",
"Is this correct?" => "是否正確?",
"Error parsing date: {date}" => "錯誤的解析日期:{date}",
"# groups" => "# groups",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "有一些聯絡人被標記為將刪除但是尚未刪除，稍等一下就會刪除了。",
"Click to undo deletion of {num} contacts" => "點一下來復原刪除 {num} 個聯絡人",
"Cancelled deletion of {num} contacts" => "取消 {num} 個聯絡人的刪除動作",
"Add" => "增加",
"Contact is already in this group." => "該聯絡人已在此群組中。",
"Contacts are already in this group." => "聯絡人皆已在此群組中。",
"Couldn't get contact list." => "無法取得聯絡人清單。",
"Contact is not in this group." => "聯絡人不在此群組中。",
"Contacts are not in this group." => "聯絡人皆不在此群組中。",
"Failed renaming group: {error}" => "重新命名群組失敗：{error}",
"A group named {group} already exists" => "群組 {group} 已經存在",
"You can drag groups to\narrange them as you like." => "你可以拖曳群組以你喜歡的方式排列。",
"Failed adding group: {error}" => "加入群組失敗：{error}",
"All" => "所有",
"Favorites" => "最愛",
"Shared by {owner}" => "由 {owner} 分享",
"Not grouped" => "不在群組裡",
"Failed loading groups: {error}" => "載入群組失敗：{error}",
"Import into..." => "匯入至…",
"Import" => "匯入",
"Close" => " 關閉",
"Error" => "錯誤",
"Displayname cannot be empty." => "顯示名稱不能留空。",
"Show CardDav link" => "顯示 CardDAV 連結",
"Show read-only VCF link" => "顯示 VCF 唯讀連結",
"Download" => "下載",
"Edit" => "編輯",
"Delete" => "刪除",
"More..." => "更多…",
"Less..." => "較少…",
"Failed loading photo: {error}" => "圖片載入失敗： {error}",
"You do not have permissions to see this contacts" => "您沒有權限檢視這個聯絡人。",
"Contact not found" => "找不到聯絡人",
"You do not have permissions to see these contacts" => "您沒有權限檢視這些聯絡人。",
"You do not have permissions add contacts to the address book" => "您沒有權限新增聯絡人至這本通訊錄。",
"The backend for this address book does not support adding contacts" => "這本通訊錄的後端不支援新增聯絡人",
"You do not have permissions to delete this contact" => "您沒有權限刪除這位聯絡人。",
"The backend for this address book does not support deleting contacts" => "這本通訊錄的後端不支援刪除聯絡人",
"Unknown error" => "未知的錯誤",
"The backend for this address book does not support updating" => "這本通訊錄的後端不支援編輯聯絡人",
"You don't have permissions to update the address book." => "您沒有權限編輯這本通訊錄。",
"You don't have permissions to delete the address book." => "您沒有權限刪除這本通訊錄。",
"Address book not found" => "找不到通訊錄",
"You do not have permissions to see this contact" => "您沒有權限檢視這個聯絡人",
"You do not have permissions to update this contact" => "您沒有權限編輯這位聯絡人",
"The backend for this contact does not support updating it" => "這個聯絡人的後端不支援編輯",
"This backend not support adding contacts" => "後端不支援新增聯絡人",
"Property not found" => "找不到這個屬性",
" Missing IM parameter for: " => "遺失的 IM 參數：",
"Unknown IM: " => "未知的 IM:",
"{name}'s Birthday" => "{name}的生日",
"Error creating address book" => "建立通訊錄出現錯誤",
"Error updating address book" => "編輯通訊錄出現錯誤",
"You do not have permissions to delete the \"%s\" address book" => "你沒有刪除\"%s\"通訊錄的權限",
"Error deleting address book" => "刪除通訊錄出現錯誤",
"Error creating contact." => "建立聯絡人出現錯誤",
"Error deleting contact." => "刪除聯絡人出現錯誤",
"Error retrieving contact." => "取得聯絡人出現錯誤",
"Error saving contact." => "儲存聯絡人時發生錯誤",
"Error removing contact from other address book." => "從其他通訊錄移除聯絡人時發生錯誤。",
"Couldn't find contact." => "找不到聯絡人",
"Error merging into contact." => "合併聯絡人資料時出現錯誤",
"Error saving contact to backend." => "儲存聯絡人資料至後端時出現錯誤",
"Property name is not set." => "尚未設定屬性名稱",
"Property checksum is not set." => "尚未設定檢查碼",
"Information about vCard is incorrect. Please reload the page." => "有關 vCard 的資訊不正確，請重新載入此頁。",
"Error getting user photo" => "取得使用者相片時發生錯誤",
"No file was uploaded. Unknown error" => "沒有檔案被上傳。未知的錯誤。",
"There is no error, the file uploaded with success" => "無錯誤，檔案上傳成功",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "上傳的檔案超過了 php.ini 中的 upload_max_filesize 設定",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
"The uploaded file was only partially uploaded" => "只有檔案的一部分被上傳",
"No file was uploaded" => "沒有檔案被上傳",
"Missing a temporary folder" => "找不到暫存資料夾",
"Couldn't load temporary image: " => "無法載入暫存圖片：",
"Couldn't save temporary image: " => "無法儲存暫存影像",
"No photo path was submitted." => "沒有提供相片路徑",
"File doesn't exist:" => "檔案不存在",
"Error loading image." => "載入影像時發生錯誤",
"Image has been removed from cache" => "圖片已經從快取中移除",
"Error creating temporary image" => "產生暫存圖片發生錯誤",
"Error cropping image" => "修剪圖片發生錯誤",
"Error resizing image" => "縮放圖片發生錯誤",
"Error getting PHOTO property." => "讀取 PHOTO 屬性時發生錯誤",
"No group name given." => "未設定群組名稱",
"Error adding group." => "新增群組錯誤",
"No group name to rename from given." => "未提供要更名的群組名稱",
"No group name to rename to given." => "未設定新群組名稱",
"Error renaming group." => "群組更名錯誤",
"Group ID missing from request." => "請求中缺少群組 ID",
"Group name missing from request." => "請求中缺少群組名稱",
"Contact ID missing from request." => "請求中缺少聯絡人 ID",
"Failed to write to disk" => "寫入硬碟失敗",
"Not enough storage available" => "儲存空間不足",
"Attempt to upload blacklisted file:" => "試圖上傳被禁止的檔案：",
"Error uploading contacts to storage." => "上傳聯絡人到儲存空間時發生錯誤",
"You do not have permissions to import into this address book." => "您沒有權限將資料匯入至這本通訊錄。",
"File name missing from request." => "請求中缺少檔名",
"Progress key missing from request." => "請求中缺少 progress key",
"Attempt to access blacklisted file:" => "試圖存取被禁止的檔案：",
"No contacts found in: " => "在這些地方找不到聯絡人：",
"No key is given." => "沒有提供鍵名",
"No value is given." => "沒有提供鍵值",
"Could not set preference: " => "無法設定偏好：",
"Contact" => "通訊錄",
"Other" => "其他",
"HomePage" => "首頁",
"Jabber" => "Jabber",
"Internet call" => "網際網路呼叫",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "工作",
"Home" => "住宅",
"Mobile" => "行動電話",
"Text" => "文字",
"Voice" => "語音",
"Message" => "訊息",
"Fax" => "傳真",
"Video" => "影片",
"Pager" => "呼叫器",
"Internet" => "網際網路",
"Friends" => "朋友",
"Family" => "親人",
"New Contact" => "新聯絡人",
"Group name" => "群組名稱",
"New Group" => "新群組",
"Address books" => "通訊錄",
"Display name" => "顯示名稱",
"Add Address Book" => "新增通訊錄",
"Select file..." => "選擇檔案…",
"(De-)select all" => "(反)全選",
"Sort order" => "排序方式",
"First- Lastname" => "名字 - 姓氏",
"Last-, Firstname" => "姓氏 - 名字",
"Groups" => "群組",
"Favorite" => "我的最愛",
"Merge selected" => "合併已選擇的項目",
"Keyboard shortcuts" => "快速鍵",
"Navigation" => "導覽",
"Next contact in list" => "清單中的下一位聯絡人",
"Previous contact in list" => "清單中的上一位聯絡人",
"Expand/collapse current addressbook" => "展開/收合目前的通訊錄",
"Next addressbook" => "下一本通訊錄",
"Previous addressbook" => "上一本通訊錄",
"Actions" => "動作",
"Refresh contacts list" => "重新整理聯絡人清單",
"Add new contact" => "新增聯絡人",
"Add new addressbook" => "新增通訊錄",
"Delete current contact" => "刪除這個聯絡人",
"<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>您的通訊錄中無聯絡人，或是您的通訊錄未啓用</h3><p>請加入新的聯絡人或從 VCF 檔案匯入聯絡人</p>",
"Add contact" => "新增聯絡人",
"Delete group" => "刪除群組",
"Rename group" => "更名群組",
"Which contact should the data be merged into?" => "要將資料匯入至哪一個聯絡人?",
"Delete the other(s) after successful merge?" => "合併成功後刪除多餘的聯絡人？",
"Compose mail" => "撰寫郵件",
"Delete current photo" => "刪除這張相片",
"Edit current photo" => "編輯目前相片",
"Upload new photo" => "上傳新照片",
"Select photo from ownCloud" => "從 ownCloud 中挑選相片",
"Name" => "名稱",
"First name" => "名子",
"Additional names" => "額外名",
"Last name" => "姓氏",
"Select groups" => "選擇群組",
"Select address book" => "選擇通訊錄",
"Nickname" => "綽號",
"Enter nickname" => "輸入綽號",
"Title" => "標題",
"Enter title" => "輸入標題",
"Organization" => "組織",
"Enter organization" => "輸入組織",
"Birthday" => "生日",
"Notes go here..." => "註釋在此處",
"Export as VCF" => "以 VCF 匯出",
"Phone" => "電話",
"Email" => "信箱",
"Instant Messaging" => "即時通訊",
"Address" => "網址",
"Note" => "註解",
"Web site" => "網站",
"Delete contact" => "刪除通訊錄",
"Preferred" => "首選",
"Please specify a valid email address." => "註填入合法的電子郵件住址",
"someone@example.com" => "someone@example.com",
"Mail to address" => "寄送住址",
"Delete email address" => "刪除電子郵件住址",
"Enter phone number" => "輸入電話號碼",
"Delete phone number" => "刪除電話號碼",
"Go to web site" => "打開網站",
"Delete URL" => "刪除 URL",
"View on map" => "在地圖上檢視",
"Delete address" => "刪除地址",
"1600 Pennsylvania Avenue, NW" => "臺中市臺灣大道10號",
"Street address" => "街道地址",
"20500" => "20500",
"Postal code" => "郵遞區號",
"Washington, DC" => "華盛頓特區",
"City" => "城市",
"District of Columbia" => "哥倫比亞特區",
"State or province" => "州或省",
"USA" => "美國",
"Country" => "國家",
"Instant Messenger" => "即時通訊軟體",
"Delete IM" => "刪除 IM",
"Active" => "作用中",
"Share" => "分享",
"Export" => "匯出",
"CardDAV link" => "顯示 CardDav 連結",
"CardDAV syncing addresses" => "CardDAV 同步位址",
"more info" => "更多資訊",
"Primary address (Kontact et al)" => "主要地址",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "電話簿",
"New Address Book" => "新電話簿",
"Description" => "描述"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/zh_TW.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "通訊錄",
"Ok" => "好",
"Cancel" => "取消",
"Save" => "儲存",
"Edit Addressbook" => "編輯電話簿",
"An address book called {name} already exists" => "通訊錄 {name} 已存在",
"Failed adding address book: {error}" => "通訊錄匯入失敗：{error}",
"Failed loading address books: {error}" => "通訊錄載入失敗：{error}",
"Server error! Please inform system administator" => "伺服器錯誤! 請通知系統管理員",
"Indexing contacts" => "正在建立聯絡人索引...",
"Unrecoverable error loading address books: {msg}" => "載入通訊錄時發生無法修正的錯誤：{msg}",
"Error." => "錯誤。",
"Add to..." => "加入至…",
"Remove from..." => "從…移除",
"Add group..." => "新增群組",
"Invalid URL: \"{url}\"" => "無效的 URL ：\"{url}\"",
"Invalid email: \"{url}\"" => "無效的電子郵件：\"{url}\"",
"Merge failed. Cannot find contact: {id}" => "合併失敗，沒有找到聯絡人：{id}",
"Merge failed." => "合併失敗。",
"Merge failed. Error saving contact." => "合併失敗，儲存聯絡人時發生錯誤。",
"Select photo" => "選擇相片",
"Network or server error. Please inform administrator." => "網路或伺服器錯誤，請通知系統管理員。",
"Error adding to group." => "新增到群組時出錯。",
"Error removing from group." => "從群組中移除出錯。",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "你已經選取了超過300個聯絡人。\n可能會導致失敗！點擊這兒繼續嘗試。",
"Error setting {name} as favorite." => "設定 {name} 為最愛時發生錯誤。",
"Merge contacts" => "合併聯絡人",
"Add group" => "新增群組",
"OK" => "好",
"Could not find contact: {id}" => "找不到聯絡人：{id}",
"Edit profile picture" => "編輯大頭貼照",
"Crop photo" => "裁切相片",
"Error parsing date: {date}" => "錯誤的解析日期:{date}",
"# groups" => "# groups",
"Error parsing birthday {bday}" => "解析生日 {bday} 時發生錯誤",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "有一些聯絡人被標記為將刪除但是尚未刪除，稍等一下就會刪除了。",
"Click to undo deletion of {num} contacts" => "點一下來復原刪除 {num} 個聯絡人",
"Cancelled deletion of {num} contacts" => "取消 {num} 個聯絡人的刪除動作",
"Add" => "增加",
"Contact is already in this group." => "該聯絡人已在此群組中。",
"Contacts are already in this group." => "聯絡人皆已在此群組中。",
"Couldn't get contact list." => "無法取得聯絡人清單。",
"Contact is not in this group." => "聯絡人不在此群組中。",
"Contacts are not in this group." => "聯絡人皆不在此群組中。",
"A group named \"{group}\" already exists" => "群組 \"{group}\" 已存在",
"Failed renaming group: {error}" => "重新命名群組失敗：{error}",
"You can drag groups to\narrange them as you like." => "你可以拖曳群組以你喜歡的方式排列。",
"Failed adding group: {error}" => "加入群組失敗：{error}",
"All" => "所有",
"Favorites" => "最愛",
"Shared by {owner}" => "由 {owner} 分享",
"Not grouped" => "不在群組裡",
"Failed loading groups: {error}" => "載入群組失敗：{error}",
"Please choose the addressbook" => "請選擇通訊錄",
"Import into..." => "匯入至…",
"Error loading import template" => "載入匯入樣板時發生錯誤",
"Import contacts" => "匯入聯絡人",
"Import" => "匯入",
"Importing..." => "匯入中…",
"Import done" => "匯入完成",
"Close" => " 關閉",
"Failed loading photo: {error}" => "圖片載入失敗： {error}",
"You do not have permissions to see this contact" => "您沒有權限檢視這個聯絡人",
"Contact not found" => "找不到聯絡人",
"You do not have permissions to see these contacts" => "您沒有權限檢視這些聯絡人。",
"You do not have permissions add contacts to the address book" => "您沒有權限新增聯絡人至這本通訊錄。",
"The backend for this address book does not support adding contacts" => "這本通訊錄的後端不支援新增聯絡人",
"You do not have permissions to delete this contact" => "您沒有權限刪除這位聯絡人。",
"The backend for this address book does not support deleting contacts" => "這本通訊錄的後端不支援刪除聯絡人",
"Unknown error" => "未知的錯誤",
"The backend for this address book does not support updating" => "這本通訊錄的後端不支援編輯聯絡人",
"You don't have permissions to delete the address book." => "您沒有權限刪除這本通訊錄。",
"Address book not found" => "找不到通訊錄",
"You do not have permissions to update this contact" => "您沒有權限編輯這位聯絡人",
"The backend for this contact does not support updating it" => "這個聯絡人的後端不支援編輯",
"Property not found" => "找不到這個屬性",
" Missing IM parameter for: " => "遺失的 IM 參數：",
"Unknown IM: " => "未知的 IM:",
"{name}'s Birthday" => "{name}的生日",
"Error creating address book" => "建立通訊錄出現錯誤",
"You do not have permissions to delete the \"%s\" address book" => "你沒有刪除\"%s\"通訊錄的權限",
"Error deleting address book" => "刪除通訊錄出現錯誤",
"Error creating contact." => "建立聯絡人出現錯誤",
"Error creating contact" => "創建聯絡人時發生錯誤",
"Error removing contact from other address book." => "從其他通訊錄移除聯絡人時發生錯誤。",
"Couldn't find contact." => "找不到聯絡人",
"Error merging into contact." => "合併聯絡人資料時出現錯誤",
"Error saving contact to backend." => "儲存聯絡人資料至後端時出現錯誤",
"Property name is not set." => "尚未設定屬性名稱",
"Property checksum is not set." => "尚未設定檢查碼",
"Information about vCard is incorrect. Please reload the page." => "有關 vCard 的資訊不正確，請重新載入此頁。",
"Error updating contact" => "更新聯絡人時發生錯誤",
"Error saving contact to backend" => "儲存聯絡人資料至後台時發生錯誤",
"Error getting user photo" => "取得使用者相片時發生錯誤",
"No photo path was submitted." => "沒有提供相片路徑",
"Error getting PHOTO property." => "讀取 PHOTO 屬性時發生錯誤",
"Error saving contact." => "儲存聯絡人時發生錯誤",
"No group name given." => "未設定群組名稱",
"Error adding group." => "新增群組錯誤",
"No group name to rename from given." => "未提供要更名的群組名稱",
"No group name to rename to given." => "未設定新群組名稱",
"Error renaming group." => "群組更名錯誤",
"Group ID missing from request." => "請求中缺少群組 ID",
"Group name missing from request." => "請求中缺少群組名稱",
"Contact ID missing from request." => "請求中缺少聯絡人 ID",
"No file was uploaded. Unknown error" => "沒有檔案被上傳。未知的錯誤。",
"There is no error, the file uploaded with success" => "無錯誤，檔案上傳成功",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "上傳的檔案超過了 php.ini 中的 upload_max_filesize 設定",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
"The uploaded file was only partially uploaded" => "只有檔案的一部分被上傳",
"No file was uploaded" => "沒有檔案被上傳",
"Missing a temporary folder" => "找不到暫存資料夾",
"Failed to write to disk" => "寫入硬碟失敗",
"Not enough storage available" => "儲存空間不足",
"Attempt to upload blacklisted file:" => "試圖上傳被禁止的檔案：",
"Error uploading contacts to storage." => "上傳聯絡人到儲存空間時發生錯誤",
"Error moving file to imports folder." => "移動檔案至匯入資料夾時發生錯誤",
"You do not have permissions to import into this address book." => "您沒有權限將資料匯入至這本通訊錄。",
"File name missing from request." => "請求中缺少檔名",
"Progress key missing from request." => "請求中缺少 progress key",
"Attempt to access blacklisted file:" => "試圖存取被禁止的檔案：",
"No key is given." => "沒有提供鍵名",
"No value is given." => "沒有提供鍵值",
"Could not set preference: " => "無法設定偏好：",
"Contact" => "通訊錄",
"Other" => "其他",
"HomePage" => "首頁",
"Jabber" => "Jabber",
"Internet call" => "網際網路呼叫",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "工作",
"Home" => "住宅",
"Mobile" => "行動電話",
"Text" => "文字",
"Voice" => "語音",
"Message" => "訊息",
"Fax" => "傳真",
"Video" => "影片",
"Pager" => "呼叫器",
"Internet" => "網際網路",
"Friends" => "朋友",
"Family" => "親人",
"New contact" => "新聯絡人",
"Group name" => "群組名稱",
"New group" => "新群組",
"Address books" => "通訊錄",
"Display name" => "顯示名稱",
"Add Address Book" => "新增通訊錄",
"Select file..." => "選擇檔案…",
"(De-)select all" => "(反)全選",
"Sort order" => "排序方式",
"First- Lastname" => "名字 - 姓氏",
"Last-, Firstname" => "姓氏 - 名字",
"Delete" => "刪除",
"Groups" => "群組",
"Download" => "下載",
"Merge" => "合併",
"Email" => "信箱",
"Phone" => "電話",
"Address" => "網址",
"Group" => "群組",
"Keyboard shortcuts" => "快速鍵",
"Navigation" => "導覽",
"Next contact in list" => "清單中的下一位聯絡人",
"Previous contact in list" => "清單中的上一位聯絡人",
"Expand/collapse current addressbook" => "展開/收合目前的通訊錄",
"Next addressbook" => "下一本通訊錄",
"Previous addressbook" => "上一本通訊錄",
"Actions" => "動作",
"Refresh contacts list" => "重新整理聯絡人清單",
"Add new contact" => "新增聯絡人",
"Add new addressbook" => "新增通訊錄",
"Delete current contact" => "刪除這個聯絡人",
"Which contact should the data be merged into?" => "要將資料匯入至哪一個聯絡人?",
"Delete the other(s) after successful merge?" => "合併成功後刪除多餘的聯絡人？",
"Compose mail" => "撰寫郵件",
"Delete current photo" => "刪除這張相片",
"Edit current photo" => "編輯目前相片",
"Upload new photo" => "上傳新照片",
"Select photo from Files" => "從檔案中選擇相片",
"Favorite" => "我的最愛",
"Name" => "名稱",
"First name" => "名子",
"Additional names" => "額外名",
"Last name" => "姓氏",
"Address book" => "通訊錄",
"Nickname" => "綽號",
"Title" => "標題",
"Organization" => "組織",
"Birthday" => "生日",
"Notes go here..." => "註釋在此處",
"Add field..." => "新增欄位...",
"Instant Messaging" => "即時通訊",
"Note" => "註解",
"Web site" => "網站",
"Preferred" => "首選",
"Please specify a valid email address." => "註填入合法的電子郵件住址",
"someone@example.com" => "someone@example.com",
"Mail to address" => "寄送住址",
"Delete email address" => "刪除電子郵件住址",
"Enter phone number" => "輸入電話號碼",
"Go to web site" => "打開網站",
"View on map" => "在地圖上檢視",
"Street address" => "街道地址",
"Postal code" => "郵遞區號",
"City" => "城市",
"State or province" => "州或省",
"Country" => "國家",
"Instant Messenger" => "即時通訊軟體",
"Active" => "作用中",
"Share" => "分享",
"Export" => "匯出",
"CardDAV link" => "顯示 CardDav 連結",
"Edit" => "編輯",
"Description" => "描述",
"Anonymous" => "匿名",
"User" => "使用者名稱",
"Password" => "密碼",
"Base DN for search" => "Base DN for search",
"Base DN" => "Base DN",
"Base DN for modification" => "Base DN for modification"
);
